@@ -119,17 +119,17 @@ class ShadowBeamlineRenderer(AbstractBeamlineRenderer):
 
                     def get_height_shift():
                         if previous_orientation == Orientations.UP:
-                            height = previous_height + (source_distance + previous_image_distance)*numpy.sin(2*numpy.abs(beam_vertical_inclination))
+                            height = previous_height + (source_distance + previous_image_distance)*numpy.sin(2*beam_vertical_inclination)
                             shift  = previous_shift
                         elif previous_orientation == Orientations.DOWN:
-                            height = previous_height - (source_distance + previous_image_distance)*numpy.sin(2*numpy.abs(beam_vertical_inclination))
+                            height = previous_height - (source_distance + previous_image_distance)*numpy.sin(2*beam_vertical_inclination)
                             shift  = previous_shift
                         if previous_orientation == Orientations.LEFT:
                             height = previous_height
-                            shift  = previous_shift - (source_distance + previous_image_distance)*numpy.sin(2*numpy.abs(beam_horizontal_inclination))
+                            shift  = previous_shift - (source_distance + previous_image_distance)*numpy.sin(2*beam_horizontal_inclination)
                         elif previous_orientation == Orientations.RIGHT:
                             height = previous_height
-                            shift  = previous_shift + (source_distance + previous_image_distance)*numpy.sin(2*numpy.abs(beam_horizontal_inclination))
+                            shift  = previous_shift + (source_distance + previous_image_distance)*numpy.sin(2*beam_horizontal_inclination)
 
                         return height, shift
 
